@@ -1,23 +1,16 @@
 use std::error::Error;
 use std::fs::{self, File};
 use std::path::{Path, PathBuf};
-use std::process::Command;
 
 use crate::cli::InstallSubcommandArgs;
 use crate::structs::Config;
-use crate::utils::{run_command_vec, get_repo_host_ssh_url};
+use crate::utils::{run_command_vec, get_repo_host_ssh_url, clone_repo};
 use crate::{REPO_DIR, MANIFEST_PATH};
 
 pub fn install_subcommand_handler(args: InstallSubcommandArgs) -> Result<(), Box<dyn Error>>{
     let url = get_repo_host_ssh_url(&args.source)?.to_string() + &args.repository;
 
-    if Path::new(REPO_DIR).exists() {
-        fs::remove_dir_all(REPO_DIR).expect("Could not clear temporary directory");
-    }
-    fs::create_dir_all(REPO_DIR).expect("Could not create temporary directory");
-
-    println!("Attempting to clone repository");
-    Command::new("git").arg("clone").arg(url).current_dir(REPO_DIR).status()?;
+    clone_repo(Path::new(REPO_DIR), &url)?;
 
     let config: Config = serde_yaml::from_reader(File::open(MANIFEST_PATH)?).unwrap();
 
